from setuptools import setup, find_packages
import os

VERSION = '0.0.0'
DESCRIPTION = 'Timeseries Package Awesome Tests'

setup(
    name = 'VinkTS',
    version = VERSION,
    author = 'sheldon shen',
    author_email = 'shenxvdong1@gmail.com',
    description = DESCRIPTION,

)